@@ -148,7 +148,12 @@ void NLilyExport::exportStaffs(QString fname, QList<NStaff> *stafflist, exportFr
 	out_ << "%                                  %" << endl;
 	out_ << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << endl << endl;
 	if (!exportDialog_->lilyVoice->isChecked()) {
-		out_ << "\\include \"paper" << exportDialog_->lilyFont->currentText() << ".ly\"" << endl << endl;
+		if (NResource::lilyProperties_.lilyProperties) {
+			out_ << "\\include \"paper" << exportDialog_->lilyFont->currentText() << ".ly\"" << endl << endl;
+		}
+		else {
+			out_ << "#(set-global-staff-size " << exportDialog_->lilyFont->currentText() <<')' << endl << endl;
+		}
 	}
 	if (exportDialog_->lilyDrumNotes->isChecked()) {
 		if (NResource::lilyProperties_.lilyProperties) {
@@ -802,7 +807,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 						inGrace = true;
 						strokenGrace = true;
 						out_ << "\\grace { ";
-						if (elem->getSubType() != INTERNAL_MARKER_OF_STROKEN_GRACE) {
+						if (!NResource::lilyProperties_.lilyVersion2 && elem->getSubType() != INTERNAL_MARKER_OF_STROKEN_GRACE) {
 							strokenGrace = false;
 							out_ << "[ ";
 						}
@@ -1112,7 +1117,7 @@ void NLilyExport::writeVoice(int staff_nr,  int voice_nr, NVoice *voi) {
 					if (chord->status_ & STAT_PART_OF_SLUR) {
 						out_ << ") ";
 					}
-					if (!inGrace && exportDialog_->lilyBeam->isChecked()) {
+					if (exportDialog_->lilyBeam->isChecked()) {
 						if ((elem->status_ & STAT_BEAMED) && !inbeam) {
 							out_ << "[ "; inbeam = true;
 						}
